@@ -20,16 +20,15 @@
 #ifndef XFCE4_CPUFREQ_LINUX_SYSFS_H
 #define XFCE4_CPUFREQ_LINUX_SYSFS_H
 
-G_BEGIN_DECLS
+#include <glib.h>
+#include <string>
 
-gboolean cpufreq_sysfs_is_available (void);
+bool cpufreq_sysfs_is_available ();
 
-gboolean cpufreq_sysfs_read (void);
+bool cpufreq_sysfs_read ();
 
-void cpufreq_sysfs_read_current (gint cpu_number);
+void cpufreq_sysfs_read_current ();
 
-void cpufreq_sysfs_read_int (gchar *file, guint *intval);
-
-G_END_DECLS
+void cpufreq_sysfs_read_uint (const std::string &file, guint *intval);
 
 #endif /* XFCE4_CPUFREQ_LINUX_SYSFS_H */
