@@ -22,17 +22,10 @@
 
 #include "xfce4-cpufreq-plugin.h"
 
-G_BEGIN_DECLS
-
-gchar*
+std::string
 cpufreq_get_human_readable_freq (guint freq, CpuFreqUnit unit);
 
-guint
-cpufreq_get_normal_freq (const gchar *freq);
-
 void
-cpufreq_warn_reset (void);
-
-G_END_DECLS
+cpufreq_warn_reset ();
 
 #endif /* XFCE4_CPUFREQ_UTILS_H */
